@@ -9,7 +9,7 @@ test_sparseMethods <- function(){
   gene.sets <- list("my_list1"= paste0("gene_", 1:2),
                     "my_list2"= paste0("gene_", 3:4))
   
-  M <- as(m, "dgCMatrix")
+  M <- as(as(as(m, "dMatrix"), "generalMatrix"), "CsparseMatrix")
   
   checkEqualsNumeric(gsva(m, gene.sets), gsva(M, gene.sets))
   checkEqualsNumeric(gsva(m, gene.sets, method="plage"), gsva(M, gene.sets, method="plage"))
